==> dojo_1.5.0+dfsg.orig.tar.gz: dojo-release-1.5.0-src+dfsg/dijit/_editor/nls/ca/commands.js <==
({
	'bold': 'Negreta',
	'copy': 'Copia',
	'cut': 'Retalla',
	'delete': 'Suprimeix',
	'indent': 'Sagnat',
	'insertHorizontalRule': 'Regle horitzontal',
	'insertOrderedList': 'Llista numerada',
	'insertUnorderedList': 'Llista de vinyetes',
	'italic': 'Cursiva',
	'justifyCenter': 'Centra',
	'justifyFull': 'Justifica',
	'justifyLeft': 'Alinea a la esquerra',
	'justifyRight': 'Alinea a la dreta',
	'outdent': 'Sagna a l\'esquerra',
	'paste': 'Enganxa',
	'redo': 'Refés',
	'removeFormat': 'Elimina el format',
	'selectAll': 'Selecciona-ho tot',
	'strikethrough': 'Ratllat',
	'subscript': 'Subíndex',
	'superscript': 'Superíndex',
	'underline': 'Subratllat',
	'undo': 'Desfés',
	'unlink': 'Elimina l\'enllaç',
	'createLink': 'Crea un enllaç',
	'toggleDir': 'Inverteix la direcció',
	'insertImage': 'Insereix imatge',
	'insertTable': 'Insereix/edita la taula',
	'toggleTableBorder': 'Inverteix els contorns de taula',
	'deleteTable': 'Suprimeix la taula',
	'tableProp': 'Propietat de taula',
	'htmlToggle': 'Font HTML',
	'foreColor': 'Color de primer pla',
	'hiliteColor': 'Color de fons',
	'plainFormatBlock': 'Estil de paràgraf',
	'formatBlock': 'Estil de paràgraf',
	'fontSize': 'Cos de la lletra',
	'fontName': 'Nom del tipus de lletra',
	'tabIndent': 'Sagnat',
	"fullScreen": "Commuta pantalla completa",
	"viewSource": "Visualitza font HTML",
	"print": "Imprimeix",
	"newPage": "Pàgina nova",
	/* Error messages */
	'systemShortcut': 'L\'acció "${0}" és l\'única disponible al navegador utilitzant una drecera del teclat. Utilitzeu ${1}.',
	'ctrlKey':'control+${0}'
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dijit/_editor/nls/ca/commands.js <==
define(
//begin v1.x content
({
	'bold': 'Negreta',
	'copy': 'Copia',
	'cut': 'Retalla',
	'delete': 'Suprimeix',
	'indent': 'Sagnat',
	'insertHorizontalRule': 'Regla horitzontal',
	'insertOrderedList': 'Llista numerada',
	'insertUnorderedList': 'Llista de vinyetes',
	'italic': 'Cursiva',
	'justifyCenter': 'Centra',
	'justifyFull': 'Justifica',
	'justifyLeft': 'Alinea a l\'esquerra',
	'justifyRight': 'Alinea a la dreta',
	'outdent': 'Sagna a l\'esquerra',
	'paste': 'Enganxa',
	'redo': 'Refés',
	'removeFormat': 'Elimina el format',
	'selectAll': 'Selecciona-ho tot',
	'strikethrough': 'Ratllat',
	'subscript': 'Subíndex',
	'superscript': 'Superíndex',
	'underline': 'Subratllat',
	'undo': 'Desfés',
	'unlink': 'Elimina l\'enllaç',
	'createLink': 'Crea un enllaç',
	'toggleDir': 'Inverteix la direcció',
	'insertImage': 'Insereix imatge',
	'insertTable': 'Insereix/edita la taula',
	'toggleTableBorder': 'Inverteix els contorns de taula',
	'deleteTable': 'Suprimeix la taula',
	'tableProp': 'Propietat de taula',
	'htmlToggle': 'Font HTML',
	'foreColor': 'Color de primer pla',
	'hiliteColor': 'Color de fons',
	'plainFormatBlock': 'Estil de paràgraf',
	'formatBlock': 'Estil de paràgraf',
	'fontSize': 'Cos de la lletra',
	'fontName': 'Nom del tipus de lletra',
	'tabIndent': 'Sagnat',
	"fullScreen": "Commuta pantalla completa",
	"viewSource": "Visualitza font HTML",
	"print": "Imprimeix",
	"newPage": "Pàgina nova",
	/* Error messages */
	'systemShortcut': 'L\'acció "${0}" és l\'única disponible al navegador utilitzant una drecera del teclat. Utilitzeu ${1}.',
	'ctrlKey':'control+${0}'
})
//end v1.x content
);
